# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .client_facing_connection_error_details_error_type import ClientFacingConnectionErrorDetailsErrorType


class ClientFacingConnectionErrorDetails(UniversalBaseModel):
    error_type: ClientFacingConnectionErrorDetailsErrorType = pydantic.Field()
    """
    ℹ️ This enum is non-exhaustive.
    """

    error_message: str
    errored_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
